@@ -13,6 +13,8 @@ except ImportError:
 
 
 class Uploader:
+    VALID_FORMATS = ('testing', 'junit')
+
     def __init__(self, client_id, client_secret):
         self._id = client_id
         self._secret = client_secret
@@ -52,9 +54,9 @@ class Uploader:
         logger.info(f'Posted info {info}')
         json.dump(info, open(info_json, 'w'))
 
-    def import_execution(self, res_xml, execution_summary, project_id, testplan_id=''):
+    def import_execution(self, res_file, execution_summary, project_id, res_format, testplan_id=''):
         """
-        :param res_xml: junit format xml file path
+        :param res_file: junit format xml file path
         :param execution_summary: test execution summary
         :param project_id: jira project id, string type
         :param testplan_id: test plan id, string type
@@ -63,12 +65,12 @@ class Uploader:
         """
         self.fetch_token()
         # if safe_mode:
-        #     updated_xml = res_xml.replace('py_result', 'xray_result').replace('.xml', '_xray.xml')
-        #     JunitXml(res_xml).dump_xray_format_xml(updated_xml)
+        #     updated_file = res_xml.replace('py_result', 'xray_result').replace('.xml', '_xray.xml')
+        #     JunitXml(res_file).dump_xray_format_xml(updated_file)
         # else:
-        #     updated_xml = res_xml
-        updated_xml = res_xml
-        url = 'https://xray.cloud.getxray.app/api/v1/import/execution/junit/multipart'
+        #     updated_file = res_file
+        updated_file = res_file
+        url = f'https://xray.cloud.getxray.app/api/v1/import/execution/{res_format}/multipart'
         headers = {
             'Authorization': f'Bearer {self._token}'
         }
@@ -76,7 +78,7 @@ class Uploader:
         self.dump_info(info_json, execution_summary, project_id, testplan_id)
         files = {
             'info': open(info_json, 'rb'),
-            'results': open(updated_xml, 'rb')
+            'results': open(updated_file, 'rb')
         }
         logger.debug('Try to import the execution into xray.')
         logger.info(f'Headers: {json.dumps(headers)}')
@@ -96,7 +98,9 @@ def parse_arguments():
                                      epilog="General purpose xray uploader.\n"
                                             "Currently either specify a testNG or a junit style xml file .\n")
 
-    parser.add_argument('-x', '--xml', required=True, help='A xml file with absolute path.')
+    parser.add_argument('-r', '--result', required=True, help='A result file with absolute path.')
+    parser.add_argument('-f', '--format', required=True,
+                        help=f'Format of the result file. Valid formats are {", ".join(Uploader.VALID_FORMATS)}')
     parser.add_argument('-pi', '--projectId', required=True,
                         help='ID of the project where the test execution is going to be created.')
     parser.add_argument('-s', '--summary', required=True, help='Summary of the test execution.')
@@ -128,8 +132,13 @@ def main_cli():
     except KeyError:
         logger.error('Either specifying "clientSecret" in the arguments or predefining the env var CLIENT_SECRET.')
         raise
+    try:
+        assert args['format'] in Uploader.VALID_FORMATS
+    except AssertionError:
+        logger.error(f'{args["format"]} is not supported now, valid formats are {", ".join(Uploader.VALID_FORMATS)}')
+        raise
     uploader = Uploader(client_id, client_secret)
-    uploader.import_execution(args['xml'], args['summary'], args['projectId'], args['testPlan'])
+    uploader.import_execution(args['result'], args['summary'], args['projectId'], args['testPlan'])
 
 
 # main_cli()
